FormatLookupException class final
A .attribute or [key] step in a field access chain failed.
- Inheritance
-
- Object
- FormattingException
- FormatLookupException
Constructors
- FormatLookupException(FormatExceptionContext context, Object? segment, Object? value)
-
const
Properties
- context → FormatExceptionContext
-
Where in the template the failure happened.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A short, fixed description of the failure class.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segment → Object?
-
The attribute name or item key that failed to resolve.
final
- value → Object?
-
The value the lookup was attempted on.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited